@@ -22,6 +22,8 @@
  * http://jasonday.home.att.net
  */
 
+#include "config.h"
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -40,14 +42,13 @@
 #include <pi-source.h>
 #include <pi-socket.h>
 #include <pi-version.h>
+#include <libmal.h>
 
 #include "libplugin.h"
 #include "syncmal.h"
-#include "libmal.h"
 
 
-
-static char *RCSID = "$Id: syncmal.c,v 1.10 2003/02/23 18:19:43 jday Exp $";
+static char *RCSID = "$Id: syncmal.c,v 1.12 2007/01/07 16:54:21 jday Exp $";
 
 /* Preferences */
 static prefType syncmal_prefs[NUM_SMPREFS] = {
@@ -88,6 +89,14 @@ static void cb_socks_address (GtkWidget *widget, GtkWidget *entry);
 static void cb_socks_port (GtkWidget *widget, GtkWidget *entry);
 static void cb_toggle_button (GtkWidget *widget, gpointer data);
 static gboolean skip_sync (void);
+static int32 cb_task (void *out, int32 *returnErrorCode, char *currentTask,
+                      AGBool bufferable);
+static int32 cb_item (void *out,
+                      int32 *returnErrorCode,
+                      int32 currentItemNumber,
+                      int32 totalItemCount,
+                      char *currentItem);
+
 
 
 /*
@@ -129,7 +138,7 @@ int plugin_help (char **text, int *width, int *height)
                    /*-------------------------------------------*/
                    "SyncMAL plugin for J-Pilot\n"
                    "version " VERSION "\n"
-                   "Jason Day (c) 2000-2002.\n"
+                   "Jason Day (c) 2000-2007.\n"
                    "jasonday@worldnet.att.net\n"
                    "http://jasonday.home.att.net\n"
                   );
@@ -197,7 +206,7 @@ int plugin_pre_sync() {
 }
 
 int plugin_sync (int sd) {
-    PalmSyncInfo * pInfo;
+    PalmSyncInfo *pInfo;
     long ivalue;
     const char *svalue;
     time_t ltime;
@@ -221,6 +230,12 @@ int plugin_sync (int sd) {
         return -1;
     }
 
+    /* create the pInfo struct */
+    pInfo = syncInfoNew();
+    if (NULL == pInfo) {
+        return -1;
+    }
+
     /* are we using a proxy? */
     jp_get_pref (syncmal_prefs, SMPREF_USE_PROXY, &ivalue, NULL);
     if (ivalue) {
@@ -229,7 +244,7 @@ int plugin_sync (int sd) {
         jp_get_pref (syncmal_prefs, SMPREF_PROXY_ADDRESS, &ivalue, &svalue);
         if (svalue) {
             jp_logf (JP_LOG_DEBUG, "plugin_sync - setting http proxy: %s\n", svalue);
-            setHttpProxy ((char *)svalue);
+            pInfo->httpProxy = strdup (svalue);
         }
         else {
             jp_logf (JP_LOG_FATAL,
@@ -244,19 +259,19 @@ int plugin_sync (int sd) {
         jp_get_pref (syncmal_prefs, SMPREF_PROXY_PORT, &ivalue, &svalue);
         if (svalue) {
             jp_logf (JP_LOG_DEBUG, "plugin_sync - setting http proxy port: %s\n", svalue);
-            setHttpProxyPort (atoi (svalue));
+            pInfo->httpProxyPort = atoi (svalue);
         }
         else {
             jp_logf (JP_LOG_INFO | JP_LOG_GUI,
                      "SyncMAL: Using default proxy port 80\n");
-            setHttpProxyPort (80);
+            pInfo->httpProxyPort = 80;
         }
 
         jp_get_pref (syncmal_prefs, SMPREF_PROXY_USERNAME, &ivalue, &svalue);
         if (svalue) {
             if (strlen (svalue)) {
                 jp_logf (JP_LOG_DEBUG, "plugin_sync - setting proxy username: %s\n", svalue);
-                setProxyUsername ((char *)svalue);
+                pInfo->proxyUsername = strdup (svalue);
             }
         }
 
@@ -264,7 +279,7 @@ int plugin_sync (int sd) {
         if (svalue) {
             if (strlen (svalue)) {
                 jp_logf (JP_LOG_DEBUG, "plugin_sync - setting proxy password: xxxxxxxx\n");
-                setProxyPassword ((char *)svalue);
+                pInfo->proxyPassword = strdup (svalue);
             }
         }
     }
@@ -275,7 +290,7 @@ int plugin_sync (int sd) {
         jp_get_pref (syncmal_prefs, SMPREF_SOCKS_ADDRESS, &ivalue, &svalue);
         if (svalue) {
             jp_logf (JP_LOG_DEBUG, "plugin_sync - setting socks address: %s\n", svalue);
-            setSocksProxy ((char *)svalue);
+            pInfo->socksProxy = strdup (svalue);
         }
         else {
             jp_logf (JP_LOG_FATAL,
@@ -290,23 +305,36 @@ int plugin_sync (int sd) {
         jp_get_pref (syncmal_prefs, SMPREF_SOCKS_PORT, &ivalue, &svalue);
         if (svalue) {
             jp_logf (JP_LOG_DEBUG, "plugin_sync - setting socks port: %s\n", svalue);
-            setSocksProxyPort (atoi (svalue));
+            pInfo->socksProxyPort = atoi (svalue);
         }
         else {
             jp_logf (JP_LOG_INFO | JP_LOG_GUI,
                      "SyncMAL: Using default SOCKS port 1080\n");
-            setSocksProxyPort (1080);
+            pInfo->socksProxyPort = 1080;
         }
     }
 
     /* call malsync */
-    pInfo = syncInfoNew();
-    if (NULL == pInfo) {
-        return -1;
-    }
-    malsync (sd, pInfo);
+    pInfo->sd = sd;
+    pInfo->taskFunc = cb_task;
+    pInfo->itemFunc = cb_item;
+
+    malsync (pInfo);
     syncInfoFree(pInfo);
 
+    if (pInfo->httpProxy) {
+        free (pInfo->httpProxy);
+    }
+    if (pInfo->proxyUsername) {
+        free (pInfo->proxyUsername);
+    }
+    if (pInfo->proxyPassword) {
+        free (pInfo->proxyPassword);
+    }
+    if (pInfo->socksProxy) {
+        free (pInfo->socksProxy);
+    }
+
     /* update the last sync time */
     time (&ltime);
     svalue = g_strdup_printf ("%ld", ltime);
@@ -875,3 +903,27 @@ static void cb_toggle_button (GtkWidget *widget, gpointer data) {
                     GPOINTER_TO_INT (data));
     }
 }
+
+static int32 cb_task (void *out, int32 *returnErrorCode, char *currentTask,
+                      AGBool bufferable)
+{
+    if (currentTask) {
+        jp_logf(JP_LOG_GUI,"%s\n", currentTask);
+    }
+    return AGCLIENT_CONTINUE;
+}
+
+static int32 cb_item (void *out,
+                      int32 *returnErrorCode,
+                      int32 currentItemNumber,
+                      int32 totalItemCount,
+                      char *currentItem)
+{
+    jp_logf(JP_LOG_GUI,".");
+    if (currentItemNumber == totalItemCount) {
+        jp_logf(JP_LOG_GUI,"\n");
+    }
+
+    return AGCLIENT_CONTINUE;
+}
+
